<?php

namespace App\Http\Controllers;

use App\Models\Category;
use App\Models\Product;
use App\Models\Series;
use App\Models\Service\ProductService;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Http\Request;
use Spatie\QueryBuilder\AllowedFilter;
use Spatie\QueryBuilder\AllowedSort;
use Spatie\QueryBuilder\QueryBuilder;

class CategoriesController extends Controller
{
    /**
     *分类
     *
     **/
    public function category(Request $request)
    {
        $id = $request->id;
        $category = Category::query()->findOrFail($id);
        $brands = Product::query()->withoutGlobalScope('stock')
            ->selectRaw('cs,max(category1)as category1,count(cs) as nums')
            ->where('category1', $category->id)->groupBy('cs')
            ->orderBy('cs', 'asc')
            ->get();
        $categories = Category::query()->where('category', '!=', '')->get();

        return view('categories.category', compact('brands', 'category', 'categories'));
    }

    public function all()
    {
        $categories = Category::query()->where('category_es', '!=', '')->get();
        return view('categories.all', compact('categories'));
    }

    /**
     *
     *品牌页面
     **/
    public function brand(Request $request)
    {
//        dd($request->cs,$request->category,$request->id);
        /**
         * @var int $id 分类category id
         * @var string $brand cs
         * @var  int $perPage 分页每页个数
         *
         **/
        $id = $request->id;
        $brand = $request->cs;
        $brand = urldecode($brand);
        $sort = $request->sort ?? '';
        $filter = $request->filter;
        $perPage = $request->get('perPage',24);
        $category = Category::query()->findOrFail($id);
        $series = Series::query()->where('cate_id', $category->id)->where('cs', $brand)->get();

        $brands = Product::query()->withoutGlobalScope('stock')->where('category1', $category->id)->selectRaw('cs,count(cs)as nums')->groupBy('cs')->get();
        $products =Product::query()->where('category1', $category->id)->where('cs', 'like', "%$brand%")
            ->paginate($perPage)->appends(request()->query());
        return view('categories.brand', compact('category', 'products', 'sort', 'brands','series','filter','brand','perPage'));
    }

    /**
     *新产品
     *
     **/
    public function new(Request $request)
    {
        $page = $request->page ?? 1;
        $perPage = 18;
        $sort = $request->sort ?? '-date';
        $filter = $request->get('filter');
        $k = $filter['k'] ?? '';
        $options = [
            'path' => $request->url()
        ];
        $products = app(ProductService::class)->getNewProducts(100, true, $page, $perPage, $options);
        return view('categories.new', compact('products','sort','perPage'));
    }

    public function hot(Request $request)
    {
        $page = $request->page ?? 1;
        $sort = $request->sort ?? '';
        $perPage = 18;
        $options = [
            'path' => $request->url()
        ];
        $products = app(ProductService::class)->getHotProducts(100, true, $page, $perPage, $options);
        return view('categories.hot', compact('products','sort'));

    }
}
