<?php

namespace App\Http\Controllers;

use App\Jobs\CheckOrderJob;
use App\Models\Cart;
use App\Models\Country;
use App\Models\Product;
use App\Utils\Paypal;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Srmklive\PayPal\Services\PayPal as PayPalClient;

class PaypalController extends Controller
{

    protected $provider;

    public function __construct()
    {

    }

    /**
     * @note paypal创建订单
     *
     **/
    public function processTransaction(Request $request)
    {
        $data = [];
        if ($request->isMethod('POST')) {
            $data = $request->all();
            $request->validate([
                'name' => 'required|min:2',
                'phone' => 'required',
                'email' => 'required|email',
                'postal' => 'required',
//                'state' => 'required',
                'city' => 'required',
                'address1' => 'required',
                'country' => 'required'
            ]);
        }
        $userId = session()->getId();
        $data = Paypal\Facade\PaypalFacade::config(['type' => 'paypal-api'])->createOrder($userId, route('successTransaction'), route('cancelTransaction'), $data);
        $provider = new PayPalClient();
        $paypalToken = $provider->getAccessToken();
        $response = $provider->createOrder($data);
//        dispatch(new CheckOrderJob($response['id'], $userId)) -> delay(now() -> addMinutes(1));
        if (isset($response['id']) && $response['id'] != null) {
            // redirect to approve href
            foreach ($response['links'] as $links) {
                if ($links['rel'] == 'approve') {
                    return redirect()->away($links['href']);
                }
            }
            return redirect()
                ->route('payFail')
                ->with('error', 'Something went wrong.');
        } else {
            return redirect()
                ->route('payFail')
                ->with('error', $response['message'] ?? 'Something went wrong.');
        }
    }


    /**
     *  paypal 创建订单成功捕获订单
     *
     **/
    public function successTransaction(Request $request)
    {
        /**
         * @var string $token paypal token
         *
         **/
        $token = $request->token;
        $userId = session()->getId();
        $provider = new PayPalClient();
//        $provider -> setApiCredentials(config('paypal'));
        $provider->getAccessToken();

        $response = $provider->capturePaymentOrder($token);
        if (isset($response['status']) && $response['status'] == 'COMPLETED') {
            //处理paypal返回的数据，信息入库
            Paypal\Facade\PaypalFacade::config(['type' => 'paypal-api'])->handleOrder($response, $userId);
            return redirect()
                ->route('paySuccess')
                ->with('success', 'Transaction complete.');
        } else {
            return redirect()
                ->route('payFail')
                ->with('error', $response['message'] ?? 'Something went wrong.');
        }
    }

    /**
     * cancel transaction.
     *取消支付
     *
     */
    public function cancelTransaction(Request $request)
    {
        return redirect()->route('cart.index');
    }

    /**
     *
     *支付表单
     **/
    public function form()
    {

        $total = 0;
        $subtotal = 0;
        $tax = 0;
        $carts = Cart::query()
            ->with('product')
            ->where('session_id', session()->getId())
            ->where('is_buy', 0)->get()->each(function ($item) use (&$subtotal) {
                $subtotal += $item->singletotal;
            });
        $tax = bcmul($subtotal, env('PAYPAL_TAX'), 2);
        $total = bcadd($subtotal, $tax, 2);
        $countries = Country::query()->where('status', 1)->get();
        return view('paypal.checkout', compact('total', 'carts', 'subtotal', 'tax', 'countries'));
    }


    /**
     * paypal 支付成功
     *
     **/
    public function paySuccess()
    {
        return view('paypal.success');
    }

    /**
     *
     *paypal 支付失败
     **/
    public function payFail()
    {
        return view('paypal.fail');

    }

    /**
     *按钮api创建订单
     *
     **/
    public function createOrder()
    {
        /**
         * @var $userId 用户id
         * @var $data   创建paypal数据
         **/
        $userId = session()->getId();
        $data = Paypal\Facade\PaypalFacade::config(['type' => 'paypal-api'])->createOrder($userId, route('successTransaction'), route('cancelTransaction'));
        $provider = new PayPalClient();
        $paypalToken = $provider->getAccessToken();
        $response = $provider->createOrder($data);
//        dispatch(new CheckOrderJob($response['id'], $userId)) -> delay(now() -> addMinutes(1));
        return response($response);
    }

    /**
     *api捕获订单
     **/
    public function captureOrder($orderId)
    {
        $userId = session()->getId();
        $provider = new PayPalClient();
        $provider->getAccessToken();
        $response = $provider->capturePaymentOrder($orderId);
        Paypal\Facade\PaypalFacade::config(['type' => 'paypal-api'])->handleOrder($response, $userId);
        return $response;
    }

    public function paypalSdkCreate()
    {
        $userId = session()->getId();
        $response = Paypal\Facade\PaypalFacade::config(['type' => 'paypal-sdk'])->createOrder($userId, route('paypal-sdk.capture'), route('paypal-sdk.cancel'), []);
        return redirect($response->getApprovalLink());

    }

    public function paypalSdkCapture(Request $request)
    {
        if ($request->isMethod('GET')) {
            $userId = session()->getId();
            Paypal\Facade\PaypalFacade::config(['type' => 'paypal-sdk'])->handleOrder($request->all(), $userId);
            return redirect()->route('paypal.success');
        }


    }
}
