<?php

namespace App\Http\Controllers;

use App\Models\Product;
use App\Models\Service\ProductService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;

class ProductController extends Controller
{
    protected object $service;

    public function __construct(ProductService $service)
    {
        $this->service = $service;
    }

    /**
     *详情页
     *
     **/
    public function show(Request $request)
    {
        /**
         * @var int $pid 产品id
         * @var string $jian jianjie1
         * @var string $cs 品牌
         **/
        $pid = $request->pid;
        $jian = $request->jian;
        $cs = $request->cs;
        $sku = $request->sku;


        $product = Product::query()->withoutGlobalScope('stock')->with('parent')
            ->where('pcode', $sku)->first();
        //路由匹配不上
        if (!$product) {
            abort(404);
        }

        //添加最近浏览产品
        $this->service->addProductRecently($product, 12);
        $abouts = Product::query()->where('category1', $product->category1)->where('pid', '!=', $product->pid)
            ->limit(8)->get();
        if (sizeof($abouts) < 3) {
            $abouts = app(ProductService::class)->getNewProducts(6);
        }
        $recently = $this->service->getProductRecently(6);
        return view('products.show', compact('product', 'jian', 'cs', 'abouts', 'recently'));
    }

    public function model(Request $request)
    {
        $product = Product::query()->where('pid', $request->pid)->firstOrFail();
        $about = Product::query()->where('pid', '!=', $product->pid)->where('category1', $product->category1)->limit(4)
            ->get();
        $jian = $request->jian;
        return view('products.model', compact('product', 'about', 'jian'));
    }

    public function getNumericBrand(): array
    {
        if (Cache::has('numeric_brand')) {
            return Cache::get('numeric_brand');
        }
        $res = Product::query()->select('cs')->where('cs', 'regexp', '[0-9]')->get()->pluck('cs')->toArray();
        Cache::put('numeric_brand', $res, 60 * 60 * 24);
        return $res;
    }
}
