<?php

namespace App\Livewire\Carts;

use App\Models\Cart;
use Livewire\Component;

class Index extends Component
{
    public function render()
    {
        $userId = session()->getId();
        $data = $this->getCarts($userId);
        return view('livewire.carts.index', $data);
    }

    public function getCarts(string $userId): array
    {
        $carts = Cart::query()->where('is_buy', 0)->where('session_id', $userId)->get();
        $subtotal = 0.00;
        foreach ($carts as $cart) {
            $subtotal = bcadd($subtotal, $cart->singletotal, 2);
        }
        $tax = bcmul(getenv('PAYPAL_TAX'), $subtotal, 2);
        $shipping = number_format(0, 2, '.');
        $total = $subtotal + $shipping + $tax;
        $total = number_format($total, 2, '.');
        $count = count($carts);
        return compact('carts', 'subtotal', 'tax', 'total','shipping','count');
    }

    public function increment(int $id):void
    {
        $cart = Cart::query()->with('product')->findOrFail($id);
        $cart->increment('numbers');
        $cart->singletotal = bcmul($cart->product->price,$cart->numbers,2);
        $cart->save();
    }

    public function decrement(int $id):void
    {
        $cart = Cart::query()->with('product')->findOrFail($id);
        if ($cart->numbers>1){
            $cart->decrement('numbers');
            $cart->singletotal = bcmul($cart->product->price,$cart->numbers,2);
            $cart->save();
        }
    }

    public  function destroy(int $id):void
    {
        Cart::query()->findOrFail($id)->delete();
    }
}
