<?php

namespace App\Models\Service;

use App\Models\Cart;
use App\Models\Product;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Support\Facades\Redis;


class ProductService
{
    protected $model;

    public function __construct(Product $product)
    {
        $this->model = $product;
    }

    /**
     *获取产品
     *
     * @param int $cateId 分类id
     * @param int $limit 取多少个
     **/
    public function getProductList(int $cateId, int $limit): Collection
    {
        return $this->model->where('category1', $cateId)->limit($limit)
            ->orderBy('pid', 'desc')->get();
    }

    /**
     *添加最近浏览产品
     *
     **/
    public function addProductRecently($res, $limit)
    {
        $recently = getenv('APP_NAME') . 'recently';
        if (!Redis::exists($recently)) {
            Redis::lpush($recently, $res->pid);
        } else {
            $leng = Redis::llen($recently);
            $recentlyProducts = Redis::lrange($recently, 0, -1);
            $key = array_search($res->pid, $recentlyProducts);
            if ($leng < $limit) {
                if ($key !== false) {
                    Redis::lrem($recently, intval($key, 10) + 1, $res->pid);
                    Redis::lpush($recently, $res->pid);
                } else {
                    Redis::lpush($recently, $res->pid);
                }
//                foreach ($recentlyProducts as $key =>$val){
//                    if ($res->id == json_decode($val)->id){
//                        dd($val);
//                    }
//                }
            } else {
                if ($key !== false) {
                    Redis::lrem($recently, intval($key, 10) + 1, $res->pid);
                    Redis::lpush($recently, $res->pid);
                } else {
                    Redis::rpop($recently);
                    Redis::lpush($recently, $res->pid);
                }
            }
        }
        return Redis::lrange($recently, 0, $limit);
    }

    /**
     *获取最近浏览产品
     *
     **/
    public function getProductRecently(int $limit = 6): object
    {
        $ids = Redis::lrange(getenv('APP_NAME') . 'recently', 0, $limit);
        return $this->model->whereIn('pid', $ids)->get();
    }

    /**
     *获取新产品
     *
     * @param int $limit 取多少条
     * @param bool $paginator 是否分页
     * @param int $page 第几页
     * @param int $perPage 一页多少产品
     * @param array $options 附加参数
     *
     **/
    public function getNewProducts(int $limit, bool $paginator = false, int $page = 1, int $perPage = 15, array $options = [])
    {
        if (!$paginator) {
            return $this->model->orderBy('pid', 'desc')->limit($limit)->get();
        }
        $new = $this->model->orderBy('pid', 'desc')->limit($limit)->get();
        $offset = ($page * $perPage) - $perPage;
        return new LengthAwarePaginator($new->slice($offset, $perPage), sizeof($new), $perPage, $page, $options);
    }

    /**
     *获取热门产品
     *
     * @param int $limit 取多少条
     * @param bool $paginator 是否分页
     * @param int $page 第几页
     * @param int $perPage 一页多少产品
     * @param array $options 附加参数
     *
     **/
    public function getHotProducts(int $limit, bool $paginator = false, int $page = 1, int $perPage = 15, array $options = [])
    {
        if (!$paginator) {
            $carts = Cart::query()->has('product')->selectRaw('max(id)as id,product_id,max(jian)as jianjie1,max(brand)as cs')->groupBy('product_id')->orderBy('id', 'desc')->limit($limit)->get();
            foreach ($carts as $cart) {
                $cart->okpcode = $cart->product->okpcode;
                $cart->price = $cart->product->price;

            }
            return $carts;
        }
        $carts = Cart::query()->has('product')->selectRaw('max(id)as id,product_id,any_value(jian)as jianjie1,max(brand)as cs')->groupBy('product_id')->orderBy('id', 'desc')->limit($limit)->get();
        foreach ($carts as $cart) {
            $cart->okpcode = $cart->product->okpcode;
            $cart->price = $cart->product->price;
            $cart->url = route('detail', [strName($cart->product->cs), $cart->jianjie1, $cart->product->category, $cart->product->pcode]);
            $cart->jianjie1 = $cart->product->jianjie1;
            $cart->jianjie2 = $cart->product->jianjie2;
            $cart->dl = $cart->product->dl;
            $cart->dy = $cart->product->dy;
            $cart->type = $cart->product->type;
            $cart->category = $cart->product->category;


        }
        $offset = ($page * $perPage) - $perPage;
        return new LengthAwarePaginator($carts->slice($offset, $perPage), sizeof($carts), $perPage, $page, $options);
    }

}
