<?php

namespace App\Providers;

use App\Models\Product;
use App\Models\Service\ProductService;
use App\Utils\Paypal\PaypalServiceProvider;
use Constantine\Admin\Models\CategorySort;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Facades\View;
use Illuminate\Support\ServiceProvider;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     */
    public function register(): void
    {
        $this->app->register(PaypalServiceProvider::class);
    }

    /**
     * Bootstrap any application services.
     */
    public function boot(): void
    {

        //分页
        Paginator::defaultView('pagination::custom');
        //头部
        View::composer('layouts.__header', function (\Illuminate\View\View $view) {
            $categories = CategorySort::query()->with('category')->where('status', 1)->orderBy('sort', 'asc')->get();
            $view->with(['nav' => $categories]);
        });
        //分类页侧边
        View::composer('categories.__left', function (\Illuminate\View\View $view) {
            $brands = Product::query()->withoutGlobalScope('stock')->selectRaw('category1,count(cs)as nums,cs')
                ->groupBy('cs', 'category1')->orderBy('nums', 'desc')->limit(15)->get();
            $product = $this->app->make(ProductService::class);
            $hot = $product->getHotProducts(12);
            $recently =$product->getProductRecently(6);
            $view->with([
                'leftBrands' => $brands,
                'leftHot' => $hot,
                'leftRecently'=>$recently
            ]);
        });

        //底部
        View::composer('layouts.__footer',function (\Illuminate\View\View $view){
            $product = $this->app->make(ProductService::class);
            $new = $product->getNewProducts(6);
            $view->with([
                'footerNew'=>$new
            ]);
        });

    }
}
