<?php

namespace Constantine\Admin;

use App\Http\Middleware\VerifyCsrfToken;
use Constantine\Admin\Http\Controllers\ShipController;
use Constantine\Admin\Http\Middleware\AdminLocale;
use Dcat\Admin\Extend\ServiceProvider;
use Dcat\Admin\Admin;
use Dcat\Admin\Layout\Menu;
use Illuminate\Support\Facades\Schema;

class AdminServiceProvider extends ServiceProvider
{
    protected $js = [
        'js/index.js',
    ];
    protected $css = [
        'css/index.css',
    ];

    public function register()
    {
        //设置后台语言
        $this->app['router']->aliasMiddleware('admin.locale', AdminLocale::class);

        $nodes =[
            [
                'id' => '1', // 此id只要保证当前的数组中是唯一的即可
                'title' => '国家管理',
                'icon' => 'fa-globe',
                'uri' => '/countries',
                'parent_id' => 0,
                'permission_id' => 'country', // 与权限绑定
                'roles' => 'administrator', // 与角色绑定
            ],
            [
                'id' => '2', // 此id只要保证当前的数组中是唯一的即可
                'title' => '数据管理',
                'icon' => 'fa-money',
                'uri' => '/countries',
                'parent_id' => 0,
                'permission_id' => 'product', // 与权限绑定
                'roles' => 'administrator', // 与角色绑定
            ],
            [
                'id' => '3', // 此id只要保证当前的数组中是唯一的即可
                'title' => '购物车管理',
                'icon' => 'fa-cart-plus',
                'uri' => 'carts',
                'parent_id' => 2,
                'permission_id' => 'product', // 与权限绑定
                'roles' => 'administrator', // 与角色绑定
            ],
            [
                'id' => '4', // 此id只要保证当前的数组中是唯一的即可
                'title' => '订单管理',
                'icon' => 'fa-reorder (alias)',
                'uri' => 'orders',
                'parent_id' => 2,
                'permission_id' => 'product', // 与权限绑定
                'roles' => 'administrator', // 与角色绑定
            ],
            [
                'id' => '5',
                'title' => '页面管理',
                'icon' => 'fa fa-cog',
                'uri' => '',
                'parent_id' => 0,
                'permission_id' => 'index',
                'roles' => 'administrator',
            ],
            [
                'id' => '6',
                'title' => '首页设置',
                'icon' => 'fa fa-cog',
                'uri' => 'index',
                'parent_id' => 5,
                'permission_id' => 'index',
                'roles' => 'administrator',
            ],
            [
                'id' => '7',
                'title' => '分类管理',
                'icon' => 'fa fa-bars',
                'uri' => '',
                'parent_id' => 0,
                'permission_id' => 'category',
                'roles' => 'administrator',
            ],
            [
                'id' => '8',
                'title' => '分类设置',
                'icon' => 'fa fa-bars',
                'uri' => 'categories',
                'parent_id' => 7,
                'permission_id' => 'category',
                'roles' => 'administrator',
            ],
            [
                'id' => '9',
                'title' => '分类排序',
                'icon' => 'fa fa-bars',
                'uri' => 'categories-sort',
                'parent_id' => 7,
                'permission_id' => 'category',
                'roles' => 'administrator',
            ],

        ];
        if (config('admin.extension.multi_databases')) {

            $nodes = array_merge($nodes,[
                [
                    'id' => '10', // 此id只要保证当前的数组中是唯一的即可
                    'title' => '数据库管理',
                    'icon' => 'fa-database',
                    'uri' => '/databases',
                    'parent_id' => 0,
                    'permission_id' => 'country', // 与权限绑定
                    'roles' => 'administrator', // 与角色绑定
                ]
            ]);

        }
        if (config('admin.extension.ship_enable')) {
            $this->app['router']->any('ship',[ShipController::class,'ship']);
            $nodes = array_merge($nodes,[
                [
                    'id' => '11', // 此id只要保证当前的数组中是唯一的即可
                    'title' => '运费管理',
                    'icon' => 'fa-truck',
                    'uri' => '/ship',
                    'parent_id' => 0,
                    'permission_id' => 'country', // 与权限绑定
                    'roles' => 'administrator', // 与角色绑定
                ]
            ]);
        }
        //后台菜单
        Admin::menu(function (Menu $menu)use ($nodes) {

            $menu->add($nodes);

        });

    }

    public function init()
    {
        parent::init();

        //

    }

    public function settingForm()
    {
        return new Setting($this);
    }
}
