<?php

namespace Constantine\Admin\Chart\Paypal;

use App\Models\Paypal;
use Carbon\Carbon;
use Carbon\CarbonPeriod;
use Constantine\Admin\Http\Controllers\PaypalController;
use Dcat\Admin\Admin;
use Dcat\Admin\Widgets\ApexCharts\Chart;
use Illuminate\Http\Request;
use Flowframe\Trend\Trend;
use Flowframe\Trend\TrendValue;
use Constantine\Admin\Chart\ClassName;
use Illuminate\Support\Facades\DB;

class OrderLineChart extends Chart
{
    use ClassName;

    /**
     * 初始化卡片内容
     *
     * @return void
     */
    public $dropdown;

    protected $id;
    protected $connection;


    public function __construct($containerSelector = null, $options = [])
    {
        $this->id = $containerSelector['dataId'] ?? null;
        $this->connection = $containerSelector['connection'] ?? 'mysql';
        parent::__construct($containerSelector, $options);

        $this->setUpOptions();
    }


    /**
     * 初始化图表配置
     */
    protected function setUpOptions()
    {
        $color = Admin::color();

        $colors = [$color->primary(), $color->primaryDarker()];

        $this->options([

            'colors' => $colors,
            'chart' => [
                'type' => 'line',
                'height' => 430,
            ],
            'xaxis' => [
                'categories' => [],
            ],
        ]);
    }

    /**
     * 处理图表数据
     */
    protected function buildData()
    {
        // 执行你的数据查询逻辑
        $data = [
            [
                'data' => [44, 55, 41, 64, 22, 43, 21]
            ],

        ];
        $categories = [2001, 2002, 2003, 2004, 2005, 2006, 2007];

        $this->withData($data);
        $this->withCategories($categories);
    }

    /**
     * 设置图表数据
     *
     * @param array $data
     *
     * @return $this
     */
    public function withData(array $data)
    {
        return $this->option('series', $data);
    }

    /**
     * 设置图表类别.
     *
     * @param array $data
     *
     * @return $this
     */
    public function withCategories(array $data)
    {
        return $this->option('xaxis.categories', $data);
    }

    /**
     * 渲染图表
     *
     * @return string
     */
    public function render()
    {
        $this->buildData();
        return parent::render();
    }

    /**
     * 处理请求
     * 如果你的图表类中包含此方法，则可以通过此方法处理前端通过ajax提交的获取图表数据的请求
     *
     * @param Request $request
     * @return mixed|void
     */
    public function handle(Request $request)
    {
        if ($id = $request->get('id')) {

            PaypalController::setRemoteConfig(intval($id));
        }
        $option = $request->get('option');
        $connection = $request->get('connection', 'mysql');
        // 获取 parameters 方法设置的自定义参数
        $timeColumn = Paypal::$timeColumn ?? 'created_at';
        $paypal = (new Paypal())->on($connection);
        $phpVersion = phpversion();
        if (floatval($phpVersion) < 8.1) {
            switch ($option) {
                case 'week':
                    $query = $paypal->selectRaw("date_format($timeColumn,'%Y-%m-%d')as y,count(*)as x ");
                    $interval = 'day';
                    $start = now()->subWeek();
                    $end = now();
                    break;
                case 'month':
                    $query = $paypal->selectRaw("date_format($timeColumn,'%Y-%m-%d')as y,count(*)as x ");
                    $interval = 'day';
                    $start = now()->subMonth();
                    $end = now();
                    break;
                case 'year':
                    $query = $paypal->selectRaw("date_format($timeColumn,'%Y-%m')as y,count(*)as x ");
                    $interval = 'month';
                    $start = now()->startOfYear();
                    $end = now();
                    break;
                default:
                    $query = $paypal->selectRaw("date_format($timeColumn,'%Y-%m-%d')as y,count(*)as x ");
                    $interval = 'day';
                    $start = now()->subWeek();
                    $end = now();
            }

            $query->whereBetween($timeColumn, [$start->format('Y-m-d H:i:s'), $end->format('Y-m-d H:i:s')]);
            $res = $query->groupBy('y')->get()->toArray();
            $period = CarbonPeriod::between(
                $start,
                $end,
            )->interval("1 $interval");
            $data = [];
            $xArray = array_column($res,'x','y');
            foreach ($period as $date) {
                if ($option === 'year') {
                    $time = $date->format('Y-m');
                } else {
                    $time = $date->format('Y-m-d');
                }
                $data[] = [
                    'y' => $time,
                    'x' => $xArray[$time] ?? 0
                ];
            }
            $x = array_column($data, 'x');
            $y = array_column($data, 'y');
        } else {
            $query = Trend::query($paypal)->dateColumn($timeColumn);
            switch ($option) {
                case 'week':
                    $data = $query->between(now()->subWeek(), now())->perDay()->count();
                    break;
                case 'month':
                    $data = $query->between(now()->subMonth(), now())->perDay()->count();
                    break;
                case 'year':
                    $data = $query->between(now()->startOfYear(), now())->perMonth()->count();
                    break;
                default:
                    $data = $query->between(now()->subWeek(), now()->addDay())->perDay()->count();
            }
            $x = $data->map(fn(TrendValue $value) => $value->aggregate)->toArray();
            $y = $data->map(fn(TrendValue $value) => $value->date)->toArray();
        }

        $this->withData([
            [
                'data' => $x,
                'name' => '销售订单',
            ]
        ]);
        $this->withCategories($y);
    }

    /**
     * 这里返回需要异步传递到 handler 方法的参数
     *
     * @return array
     */
    public function parameters(): array
    {
        return [
            'id' => $this->id,
            'connection' => $this->connection,
        ];
    }


}
