<?php

namespace Constantine\Admin\Http\Controllers;

use App\Models\Cart;
use Dcat\Admin\Actions\Action;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Widgets\Card;

class CartController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make((new Cart())->with('product'), function (Grid $grid) {
            $grid->model()->orderBy('id', 'desc');
            $grid->quickSearch(['jian', 'brand', 'product.pcode', 'product.jianjie1', 'product.jianjie2']);
            $grid->column('id')->sortable();
            $grid->column('session_id');
            $grid->column('product_id')->expand(function (Grid\Displayers\Expand $expand) {
                $product = $this->product;
                $html = <<<HTML
    <table class="table">
    <thead><tr>
    <th>jianjie1</th> <th>pcode</th> <th>img</th> <th>price</th>
</tr></thead>
<tbody>
<tr>
    <td>{$product->jianjie1}</td> <td>{$product->pcode}</td><td><img width="100px" src="{$product->okpcode}" alt=""></td><td>{$product->price_symbol}</td>
</tr>
</tbody>
</table>
HTML;

                $card = Card::make()->content($html);
                return $card;
            });
            $grid->column('jian');
            $grid->column('brand');
            $grid->column('numbers');
            $grid->column('singletotal');
            $grid->column('baseprice');
            $grid->column('ip');
            $grid->column('is_buy');
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();

            $grid->tools(function (Grid\Tools $tools) {
                $tools->disableFilterButton();
                $tools->disableRefreshButton();
            });
            $grid->disableActions();

            $grid->disableCreateButton();
            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');

            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new Cart(), function (Show $show) {
            $show->field('id');
            $show->field('session_id');
            $show->field('product_id');
            $show->field('jian');
            $show->field('brand');
            $show->field('numbers');
            $show->field('singletotal');
            $show->field('baseprice');
            $show->field('ip');
            $show->field('is_buy');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new Cart(), function (Form $form) {
            $form->display('id');
            $form->text('session_id');
            $form->text('product_id');
            $form->text('jian');
            $form->text('brand');
            $form->text('numbers');
            $form->text('singletotal');
            $form->text('baseprice');
            $form->text('ip');
            $form->text('is_buy');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
