<?php

namespace Constantine\Admin\Http\Controllers;

use Constantine\Admin\Models\Category;
use Constantine\Admin\Models\CategorySort;
use Dcat\Admin\Admin;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Layout\Content;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;
use Illuminate\Support\Facades\DB;

class CategorySortController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new CategorySort(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('category_id');
            $grid->column('status');
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();

            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');

            });
            //关闭新增按钮
            $grid->disableCreateButton();
            //工具栏
            $grid->tools(function (Grid\Tools $tools) {
                $tools->disableFilterButton();
                $tools->disableRefreshButton();
                $tools->disableBatchActions();
                $url = admin_url('/categories-sort/create');
                $button = sprintf('<a class="btn btn-success" target="_blank" onclick="window.location=\'%s\'">编辑排序</a>', $url);
                $tools->append($button);
            });
            $grid->disableActions();
            $grid->actions(function (Grid\Displayers\Actions $actions) {
                $actions->append('<a>编辑排序按钮</a>');
            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new CategorySort(), function (Show $show) {
            $show->field('id');
            $show->field('category_id');
            $show->field('status');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {

        return Form::make(new CategorySort(), function (Form $form) {
            $form->display('id');
            $form->text('category_id');
            $form->text('status');
            $form->display('created_at');
            $form->display('updated_at');
        });
    }

    public function create(Content $content)
    {
        Admin::js('vendor/dcat-admin/dcat/plugins/sortable/Sortable.min.js');
        Admin::js('vendor/dcat-admin/dcat/plugins/layer/layer.js');
        $style = <<<style
    .category-sort-button button{
        margin:5px;
    }
style;

        Admin::style($style);
        $categoriesSort = CategorySort::query()->with('category')->get();
        if(sizeof($categoriesSort)>0){
            $categories = Category::query()->with('sort')->whereIn('id',$categoriesSort->pluck('category_id')->toArray())->get();
        }else{
            $categories = Category::query()->with('sort')->get();
        }
        return $content
            ->translation($this->translation())
            ->title($this->title())
            ->description($this->description()['create'] ?? trans('admin.create'))
            ->body(admin_view('constantine.admin::admin.category-sorts.edit', compact('categories')));
    }

    public function store()
    {
        $data = request()->all();
        $data = $data['data'];
        $sort = $data['sort'];
        $status = $data['status'];
        $insert = [];
        $time = now();
        foreach ($sort as $k=> $val) {
            $insert[] = [
                'category_id' => $val,
                'status' => $status[$val],
                'sort' => $k,
                'created_at' => $time,
                'updated_at' => $time
            ];
        }
        DB::raw('truncate table category_sorts');
        CategorySort::truncate();
        DB::table('category_sorts')->insert($insert);
        return response()->json([
            'code'=>0,
            'status'=>'success'
        ]);
    }
}
