<?php

namespace Constantine\Admin\Http\Controllers;

use Constantine\Admin\Models\Country;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class CountryController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new Country(), function (Grid $grid) {
            $grid->quickSearch(['name','iso2','iso3','translations']);
            $grid->showColumnSelector();
            $grid->model()->orderBy('status', 'desc');
            $grid->column('id')->sortable();
            $grid->column('name');
            $grid->column('iso3');
            $grid->column('numeric_code');
            $grid->column('iso2');
            $grid->column('phonecode');
            $grid->column('capital')->hide();
            $grid->column('currency');
            $grid->column('currency_symbol');
            $grid->column('tld')->hide();
            $grid->column('native')->hide();
            $grid->column('region')->hide();
            $grid->column('subregion')->hide();
            $grid->column('timezones')->hide();
            $grid->column('translations')->hide();
            $grid->column('latitude')->hide();
            $grid->column('longitude')->hide();
            $grid->column('emoji')->hide();
            $grid->column('emojiU')->hide();
            $grid->column('flag')->hide();
            $grid->column('wikiDataId')->hide();
            $grid->column('status', '状态')->switch();
            $grid->column('color')->hide();
            $grid->column('created_at')->hide();
            $grid->column('updated_at')->hide();

            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');
            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new Country(), function (Show $show) {
            $show->field('id');
            $show->field('name');
            $show->field('iso3');
            $show->field('numeric_code');
            $show->field('iso2');
            $show->field('phonecode');
            $show->field('capital');
            $show->field('currency');
            $show->field('currency_symbol');
            $show->field('tld');
            $show->field('native');
            $show->field('region');
            $show->field('subregion');
            $show->field('timezones');
            $show->field('translations');
            $show->field('latitude');
            $show->field('longitude');
            $show->field('emoji');
            $show->field('emojiU');
            $show->field('flag');
            $show->field('wikiDataId');
            $show->field('status');
            $show->field('color');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new Country(), function (Form $form) {
            $form->display('id');
            $form->text('name');
            $form->text('iso3');
            $form->text('numeric_code');
            $form->text('iso2');
            $form->text('phonecode');
            $form->text('capital');
            $form->text('currency');
            $form->text('currency_symbol');
            $form->text('tld');
            $form->text('native');
            $form->text('region');
            $form->text('subregion');
            $form->text('timezones');
            $form->text('translations');
            $form->text('latitude');
            $form->text('longitude');
            $form->text('emoji');
            $form->text('emojiU');
            $form->text('flag');
            $form->text('wikiDataId');
            $form->text('status');
            $form->text('color');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
