<?php

namespace Constantine\Admin\Http\Controllers;

use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Show;
use Constantine\Admin\Models\Database;

class DatabaseController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(new Database(), function (Grid $grid) {
            $grid->column('id')->sortable();
            $grid->column('ip');
            $grid->column('port');
            $grid->column('database');
            $grid->column('username');
            $grid->column('password');
            $grid->column('url');
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();

            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');

            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new Database(), function (Show $show) {
            $show->field('id');
            $show->field('ip');
            $show->field('port');
            $show->field('database');
            $show->field('username');
            $show->field('password');
            $show->field('url');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new Database(), function (Form $form) {
            $form->display('id');
            $form->text('ip');
            $form->text('port');
            $form->text('database');
            $form->text('username');
            $form->text('password');
            $form->text('url');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
