<?php

namespace Constantine\Admin\Http\Controllers;

use Constantine\Admin\Models\Index;
use Constantine\Admin\Models\Category;
use Dcat\Admin\Admin;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class IndexController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {

        return Grid::make(Index::with('category'), function (Grid $grid) {

            $grid->model()->orderBy('sort','asc');
            $grid->column('id')->sortable();
            $grid->column('name');
            $grid->column('category.category');
            $grid->column('limit')->editable();
            $grid->column('created_at');
            $grid->column('updated_at')->sortable();
            $grid->column('status')->switch();
            $grid->tools(function (Grid\Tools $tools) {
                $tools->disableFilterButton();
                $tools->disableRefreshButton();
            });
            $grid->filter(function (Grid\Filter $filter) {
                $filter->equal('id');

            });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new Index(), function (Show $show) {
            $show->field('id');
            $show->field('name');
            $show->field('category_id');
            $show->field('limit');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        if (config('admin.index')) {
            $options = config('admin.index');
        } else {
            $options = [
                'top_1', 'top_2', 'mid', 'footer_1', 'footer_2'
            ];
        }

        $name = Index::query()->get()->pluck('name')->toArray();
        $categories =  Index::query()->where('status',1)->get()->pluck('category_id')->toArray();
        return Form::make((new Index())->with(['category','categories']), function (Form $form) use ($options, $name,$categories) {

            $form->display('id');
            if ($form->isCreating()) {
                $options = array_diff($options, $name);
            }
            if ($form->isEditing()) {

                $form->text('name')->disable();
            } else {
                $js = <<<JS
                $('select[name="name"]').on('change',function() {
                  let value = $(this).val();
                  let sort;

                  if (value.includes('top')){
                      sort=1;
                  }

                  if (value.includes('mid')){
                      sort=2;
                  }
                   if (value.includes('footer')){
                      sort=3;
                  }
                    $('select[name="sort"]').val(sort);
                    $('select[name="sort"]').trigger('change');
                })
JS;

                Admin::script($js);
                $form->select('name')->options(array_combine($options, $options));
            }

            $form->select('category_id')->options(Category::query()->whereNotIn('id',$categories)->get()->pluck('category', 'id'))->label('选择分类');
            $form->number('limit')->default(8)->label('取出数量');
            $form->switch('status')->saving(function ($v) {
                return intval($v);
            })->default(1);
            $form->select('sort','排序')->options(array_combine(range(1,4),range(1,4)))
                ->help('列表从小到大排序');
            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
