<?php

namespace Constantine\Admin\Http\Controllers;

use App\Models\Paypal;
use Constantine\Admin\Actions\Grid\BuyerInfoModal;
use Constantine\Admin\Actions\Grid\CreateDatabase;
use Constantine\Admin\Actions\Grid\SelectDomain;
use Constantine\Admin\Chart\LazyOrderLine;
use Constantine\Admin\Chart\Paypal\OrderLineChart;
use Constantine\Admin\Chart\Paypal\OrderTotalLineChart;
use Constantine\Admin\Http\Actions\Grid\MultiableWebs;
use Constantine\Admin\Models\Admin\Database;
use Dcat\Admin\Admin;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Layout\Content;
use Dcat\Admin\Show;
use Dcat\Admin\Widgets\Modal;
use Dcat\Admin\Widgets\Tab;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\Schema;

class PaypalController extends AdminController
{

    protected string $connection = 'mysql';
    public ?int $databaseId = null;

    public function __construct()
    {
        if (\config('admin.extension.multi_databases') && request()->has('data-id')) {
            $this->databaseId = $id = request()->get('data-id');
            static::setRemoteConfig($id);
            $this->connection = 'remote';
        }

    }

    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {

        Admin::script(<<<JS
        $('#grid-table >tbody > tr').on('dblclick',function() {
        let elem =$(this).find('td').eq(5);
        let modalElem =$($(elem).find('span').data('target'));
          modalElem.modal('show');
        });

JS
        );


        return Grid::make((new Paypal())->on($this->connection), function (Grid $grid) {
            $grid->model()->orderBy('created_at', 'desc');
//            $grid->header('<h4 class="alter alert-danger mt-2 mb-2 text-center">双击行可录单</h4>');
            $grid->quickSearch([
                'session_id', 'trans_id', 'local_id', 'payer_id', 'order_id', 'name', 'phone', 'email', 'ip', 'des'
            ]);
            $grid->showColumnSelector();
            $grid->column('created_at');
            $grid->column('total');
            $grid->column('currency');
            $grid->column('des');
            $grid->column('session_id')->hide()->hide();
            $grid->column('trans_id')->modal(function ($modal) {

                return BuyerInfoModal::make(['connection' => $this->connection,
                    'database_id' => request()->get('data-id'),
                ]);
            });
            $grid->column('payer_id');
            $grid->column('local_id');
            $grid->column('order_id');
            $grid->column('name');
            $grid->column('phone');
            $grid->column('email');
            $grid->column('postal');
            $grid->column('country');
            $grid->column('state')->hide();
            $grid->column('city')->hide();
            $grid->column('street1')->hide();
            $grid->column('street2')->hide();
            $grid->column('ip');

            $grid->tools(function (Grid\Tools $tools) {
                $tools->disableRefreshButton();
                if (config('admin.extension.multi_databases')) {
                    if (!Schema::hasTable('databases')) {
                        Schema::connection('mysql')->create('databases', function (Blueprint $table) {
                            $table->id();
                            $table->string('ip');
                            $table->unsignedInteger('port')->default(3306);
                            $table->string('database');
                            $table->string('username');
                            $table->string('password');
                            $table->string('url');
                            $table->timestamps();
                        });
                    }
                    $tools->append(Modal::make()->title('选择网站')->body(SelectDomain::make())->button("<button class='btn btn-primary'>选择网站</button>"));
                }
            });

            $grid->disableCreateButton();

            $grid->filter(function (Grid\Filter $filter) {
                $filter->like('trans_id');
                $filter->like('session_id');
                $filter->like('local_id');
                $filter->like('order_id');
                $filter->like('email');
                $filter->like('ip');
                $filter->like('phone');
                $filter->like('name');
            })->header(function () {
                $content = new Content();
                $tab = Tab::make()->theme();
                $tab->style('margin-top:20px;margin-bottom:20px');
                $tab->add('订单量', LazyOrderLine::make(['object' => OrderLineChart::getClassName(),
                    'connection' => $this->connection,
                    'data-id' => $this->databaseId,
                ]));
                $tab->add('销售额', LazyOrderLine::make(['object' => OrderTotalLineChart::getClassName(),
                    'connection' => $this->connection,
                    'data-id' => $this->databaseId,
                ]));
                return $tab->withCard();
            });

        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new Paypal(), function (Show $show) {
            $show->field('id');
            $show->field('session_id');
            $show->field('trans_id');
            $show->field('payer_id');
            $show->field('local_id');
            $show->field('order_id');
            $show->field('name');
            $show->field('phone');
            $show->field('email');
            $show->field('postal');
            $show->field('country');
            $show->field('state');
            $show->field('city');
            $show->field('street1');
            $show->field('street2');
            $show->field('ip');
            $show->field('total');
            $show->field('currency');
            $show->field('des');
            $show->field('created_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new Paypal(), function (Form $form) {
            $form->display('id');
            $form->text('session_id');
            $form->text('trans_id');
            $form->text('payer_id');
            $form->text('local_id');
            $form->text('order_id');
            $form->text('name');
            $form->text('phone');
            $form->text('email');
            $form->text('postal');
            $form->text('country');
            $form->text('state');
            $form->text('city');
            $form->text('street1');
            $form->text('street2');
            $form->text('ip');
            $form->text('total');
            $form->text('currency');
            $form->text('des');
            $form->text('created_at');
        });
    }

    public static function setRemoteConfig(int $id): array
    {
        $database = Database::query()->findOrFail($id);
        \DB::purge();
        Config::set('database.connections.remote', [
            'driver' => 'mysql',
            'host' => $database->ip,
            'port' => $database->port,
            'database' => $database->database,
            'username' => $database->username,
            'password' => $database->password,
            'unix_socket' => env('DB_SOCKET', ''),
            'charset' => 'utf8mb4',
            'collation' => 'utf8mb4_unicode_ci',
        ]);
        return $database->toArray();
    }
}
