<?php

namespace Constantine\Admin\Models;

use Illuminate\Database\Eloquent\Model;
use App\Models\Category;
use App\Models\Product;

/**
 *首页产品设置模型
 * @property  string $name
 * @property int $category_id
 * @property  int $limit 数据库取出数量
 * @property int $status 状态
 * @property string $created_at
 * @property string $updated_at
 * @property Category $category
 * @property Product $product
 **/
class Index extends Model
{
    protected $table = 'index';
    protected $guarded = [];

    protected $casts = [
        'created_at' => 'datetime:Y-m-d H:i:s',
        'updated_at' => 'datetime:Y-m-d H:i:s',
    ];

    public function category()
    {
        return $this->hasOne(Category::class, 'id', 'category_id');
    }

    public function categories()
    {
        return $this->hasOne(Category::class, 'id', 'category_id');
    }


    public function products()
    {
        return $this->hasMany(Product::class, 'category1', 'category_id');
    }

    public static function getProducts()
    {
        $category = self::query()->with('category')->get()->map(function (self $index) {
            $index->setRelation('products', $index->products()->orderBy('pid', 'desc')->take($index->limit)->get());
            return $index;
        });

        return $category;
    }
}
